pub enum Attestation {
Pending(String),
BitcoinBlockHeader(u32),
LitecoinBlockHeader(u32),
}Expand description
An attestation on a terminal message of the proof tree.
Variants
Pending(String)
Commitment recorded at a remote calendar for future attestation (URI).
BitcoinBlockHeader(u32)
Anchored in the Bitcoin block header chain at a height.
LitecoinBlockHeader(u32)
Anchored in the Litecoin block header chain at a height.